@@ -14,7 +14,7 @@
 #   limitations under the License.
 
 __author__ = 'Michael Gruber'
-__version__ = '0.2.2'
+__version__ = '0.2.3'
 
 __all__ = ['ANY_ARGUMENT',
            'ANY_ARGUMENTS',
@@ -47,13 +47,13 @@ from fluentmock.exceptions import (CouldNotVerifyCallError,
                                    InvalidUseOfAnyArgumentsError,
                                    NoCallsStoredError,
                                    HasBeenCalledWithUnexpectedArgumentsError)
-from fluentmock.matchers import FluentMatcher, FluentAnyArguments, FluentAnyArgument, NeverMatcher
+from fluentmock.matchers import AtLeastOnceMatcher, FluentMatcher, FluentAnyArguments, FluentAnyArgument, NeverMatcher
 
 LOGGER = getLogger(__name__)
 
 ANY_ARGUMENT = FluentAnyArgument()
 ANY_ARGUMENTS = FluentAnyArguments()
-AT_LEAST_ONCE = 'AT-LEAST-ONCE'
+AT_LEAST_ONCE = AtLeastOnceMatcher()
 NEVER = NeverMatcher()
 
 _configurators = {}
@@ -288,7 +288,7 @@ class Verifier(FluentTarget):
 
         if times not in [NEVER, AT_LEAST_ONCE]:
             error_message = 'Argument times can be "{never}" or "{once}".'.format(never=NEVER.__class__.__name__,
-                                                                                  once=AT_LEAST_ONCE)
+                                                                                  once=AT_LEAST_ONCE.__class__.__name__)
             raise ValueError(error_message)
 
         self._times = times
@@ -334,34 +334,33 @@ class Verifier(FluentTarget):
             expected_call_entry = FluentCallEntry(self.object, self.attribute_name, arguments, keyword_arguments)
             raise HasBeenCalledAtLeastOnceError(expected_call_entry)
 
-        if self._times == AT_LEAST_ONCE:
-            if matching_call_entries == 0:
-                method_of_mock = getattr(self.object, self.attribute_name)
-                if isinstance(self.object, Mock) and isinstance(method_of_mock, Mock):
-                    self._ensure_no_matchers_in_arguments(arguments, keyword_arguments)
+        if self._times is AT_LEAST_ONCE and not AT_LEAST_ONCE.matches(matching_call_entries):
+            method_of_mock = getattr(self.object, self.attribute_name)
+            if isinstance(self.object, Mock) and isinstance(method_of_mock, Mock):
+                self._ensure_no_matchers_in_arguments(arguments, keyword_arguments)
 
-                    method_of_mock.assert_called_with(*arguments, **keyword_arguments)
-                else:
-                    expected_call_entry = FluentCallEntry(self.object, self.attribute_name,
-                                                          arguments, keyword_arguments)
-                    if not _call_entries:
-                        raise NoCallsStoredError(expected_call_entry)
+                method_of_mock.assert_called_with(*arguments, **keyword_arguments)
+            else:
+                expected_call_entry = FluentCallEntry(self.object, self.attribute_name,
+                                                      arguments, keyword_arguments)
+                if not _call_entries:
+                    raise NoCallsStoredError(expected_call_entry)
 
-                    found_calls = []
+                found_calls = []
 
-                    for call_entry in _call_entries:
-                        target = call_entry.target
-                        if target.is_equal_to(self.object, self.attribute_name):
-                            found_calls.append(call_entry)
+                for call_entry in _call_entries:
+                    target = call_entry.target
+                    if target.is_equal_to(self.object, self.attribute_name):
+                        found_calls.append(call_entry)
 
-                    if found_calls:
-                        if arguments and ANY_ARGUMENTS in arguments:
-                            if len(arguments) > 1:
-                                raise InvalidUseOfAnyArgumentsError()
-                            return
-                        raise HasBeenCalledWithUnexpectedArgumentsError(expected_call_entry, found_calls)
+                if found_calls:
+                    if arguments and ANY_ARGUMENTS in arguments:
+                        if len(arguments) > 1:
+                            raise InvalidUseOfAnyArgumentsError()
+                        return
+                    raise HasBeenCalledWithUnexpectedArgumentsError(expected_call_entry, found_calls)
 
-                    raise CouldNotVerifyCallError(expected_call_entry)
+                raise CouldNotVerifyCallError(expected_call_entry)
 
 
 def create_mock(*arguments, **keyword_arguments):
